@@ -6,7 +6,7 @@ class ScannerTest():
 
         :return starbase.client.Scanner: Creates and returns a class::`starbase.client.Scanner` instance.
         """
-        url = '%s/scanner' % self.name
+        url = '{0}/scanner'.format(self.name)
         response = HttpRequest(connection=self.connection, url=url, method=PUT).get_response()
         scanner_url = response.raw.headers.get('location')
 
