@@ -1,6 +1,4 @@
-__title__ = 'starbase.client.table'
-__version__ = '0.2.4'
-__build__ = 0x000002
+__title__ = 'starbase.client.table.__init__'
 __author__ = 'Artur Barseghyan'
 __all__ = ('Table',)
 
@@ -344,7 +342,7 @@ class Table(object):
 
         if 1 == len(columns):
             cf = list(columns.keys())[0]
-            url = "{table_name}/{row}/{cf}".format(table_name=self.name, row=row, cf=cf)
+            url = "{table_name}/{row}/{cf}".format(table_name=self.name, row=row_hash, cf=cf)
         else:
             url = "{table_name}/{row}".format(table_name=self.name, row=row_hash)
 
