@@ -1,6 +1,4 @@
 __title__ = 'starbase.client.table.batch'
-__version__ = '0.2.4'
-__build__ = 0x000002
 __author__ = 'Artur Barseghyan'
 __all__ = ('Batch',)
 
@@ -53,7 +51,7 @@ class Batch(object):
         self._stack.append(data)
 
         if self.size and len(self._stack) > self.size:
-            self.process()
+            self.commit()
 
     def insert(self, row, columns, timestamp=None):
         return self._put(row, columns, timestamp=timestamp, encode_content=True)
